import unittest
from parameterized import parameterized
from core.types import Finding, FindingType, Severity, RelatedConfig, WellDoneRating, Violation


class FindingTests(unittest.TestCase):
    related_config_1 = RelatedConfig()
    related_config_1.config_id = "bucket.lifecycle_configuration.rules[0].id"
    related_config_1.preferred_value = "VersioningLifecycleManagementRule"
    related_config_1.comment = "change name to a name for your rule"

    related_config_2 = RelatedConfig()
    related_config_2.config_id = "bucket.lifecycle_configuration.rules[0].status"
    related_config_2.preferred_value = "Enabled"

    related_configs = [related_config_1, related_config_2]

    @parameterized.expand(
        [
            [Finding(
                finding_type=FindingType.DesignGap,
                gap="S3 Lifecycle configuration is not defined",
                rating=Severity.Critical,
                desc="Define the appropriate lifecycle configuration",
                config_id='bucket.lifecycle_configuration',
                related_configs=related_configs),
                False,
                'Design Gap Finding w/ Related Configs - No Exceptions'
            ],
            [Finding(
                finding_type=FindingType.ResourceGap,
                gap="Dynamo DB tables are not globally available",
                rating=Severity.High,
                desc="Since your design preference is to have a globally available database, use DynamoDB Global tables instead",
                config_id='db'),
                False,
                'Resource Gap Finding - No Exceptions'
            ],
            [Finding(
                finding_type=FindingType.Kudos,
                config_id='key.algorithm',
                desc="Key algorithm is set to AES-GCM",
                rating=WellDoneRating.Amazing),
                False,
                'Well Done Finding - No Exceptions'
            ],
            [Finding(
                FindingType.Task,
                req_id='Oak9.Req.KM.1',
                desc="Ensure that a breakglass account is created for AWS and follow best practices here"),
                False,
                'Task Finding - No Exceptions'
            ]
        ]
    )
    def test_finding(self, finding: Finding, ex: bool, description: str):
        if ex:
            self.assertIsInstance(finding, Finding, description)
        else:
            self.assertNotIsInstance(finding, Finding, description)

    @parameterized.expand(
        [
            [Violation(
                config_id='a.b.c',
                config_gap='Gap',
                config_fix='fix',
                config_value='9',
                preferred_value='10',
                additional_guidance='additional guidance',
                documentation='https://www.oak9.io',
                adjusted_severity=Severity.Moderate,
                severity=Severity.High
            ),
                'Design Gap Finding w/ Related Configs - No Exceptions'
            ]

        ]
    )
    def test_finding(self, finding: Finding, description: str):
        self.assertIsInstance(finding, Finding, description)


if __name__ == '__main__':
    unittest.main()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EssentialContactsContactXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___EssentialContactsContactXTimeouts = EssentialContactsContactXTimeouts

@typing_extensions.final
class EssentialContactsContact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LANGUAGE_TAG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NOTIFICATION_CATEGORY_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    email: builtins.str
    id: builtins.str
    language_tag: builtins.str
    name: builtins.str
    @property
    def notification_category_subscriptions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    parent: builtins.str
    @property
    def timeouts(self) -> global___EssentialContactsContactXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        id: builtins.str = ...,
        language_tag: builtins.str = ...,
        name: builtins.str = ...,
        notification_category_subscriptions: collections.abc.Iterable[builtins.str] | None = ...,
        parent: builtins.str = ...,
        timeouts: global___EssentialContactsContactXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "id", b"id", "language_tag", b"language_tag", "name", b"name", "notification_category_subscriptions", b"notification_category_subscriptions", "parent", b"parent", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___EssentialContactsContact = EssentialContactsContact



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_eventarc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_eventarc.proto\x12\x18oak9.tython.gcp.eventarc\x1a\x13shared/shared.proto\"\\\n+EventarcTriggerXDestinationXCloudRunService\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\"v\n\x1f\x45ventarcTriggerXDestinationXGke\x12\x0f\n\x07\x63luster\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0f\n\x07service\x18\x05 \x01(\t\"\xf1\x01\n\x1b\x45ventarcTriggerXDestination\x12\x16\n\x0e\x63loud_function\x18\x01 \x01(\t\x12\x10\n\x08workflow\x18\x02 \x01(\t\x12`\n\x11\x63loud_run_service\x18\x03 \x01(\x0b\x32\x45.oak9.tython.gcp.eventarc.EventarcTriggerXDestinationXCloudRunService\x12\x46\n\x03gke\x18\x04 \x01(\x0b\x32\x39.oak9.tython.gcp.eventarc.EventarcTriggerXDestinationXGke\"V\n EventarcTriggerXMatchingCriteria\x12\x11\n\tattribute\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"J\n\x18\x45ventarcTriggerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"G\n EventarcTriggerXTransportXPubsub\x12\x14\n\x0csubscription\x18\x01 \x01(\t\x12\r\n\x05topic\x18\x02 \x01(\t\"g\n\x19\x45ventarcTriggerXTransport\x12J\n\x06pubsub\x18\x01 \x01(\x0b\x32:.oak9.tython.gcp.eventarc.EventarcTriggerXTransportXPubsub\"\x8c\x05\n\x0f\x45ventarcTrigger\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x45\n\x06labels\x18\x04 \x03(\x0b\x32\x35.oak9.tython.gcp.eventarc.EventarcTrigger.LabelsEntry\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x17\n\x0fservice_account\x18\x08 \x01(\t\x12\x0b\n\x03uid\x18\t \x01(\t\x12\x13\n\x0bupdate_time\x18\n \x01(\t\x12J\n\x0b\x64\x65stination\x18\x0b \x01(\x0b\x32\x35.oak9.tython.gcp.eventarc.EventarcTriggerXDestination\x12U\n\x11matching_criteria\x18\x0c \x03(\x0b\x32:.oak9.tython.gcp.eventarc.EventarcTriggerXMatchingCriteria\x12\x44\n\x08timeouts\x18\r \x01(\x0b\x32\x32.oak9.tython.gcp.eventarc.EventarcTriggerXTimeouts\x12\x46\n\ttransport\x18\x0e \x01(\x0b\x32\x33.oak9.tython.gcp.eventarc.EventarcTriggerXTransport\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_eventarc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EVENTARCTRIGGER_LABELSENTRY._options = None
  _EVENTARCTRIGGER_LABELSENTRY._serialized_options = b'8\001'
  _EVENTARCTRIGGERXDESTINATIONXCLOUDRUNSERVICE._serialized_start=73
  _EVENTARCTRIGGERXDESTINATIONXCLOUDRUNSERVICE._serialized_end=165
  _EVENTARCTRIGGERXDESTINATIONXGKE._serialized_start=167
  _EVENTARCTRIGGERXDESTINATIONXGKE._serialized_end=285
  _EVENTARCTRIGGERXDESTINATION._serialized_start=288
  _EVENTARCTRIGGERXDESTINATION._serialized_end=529
  _EVENTARCTRIGGERXMATCHINGCRITERIA._serialized_start=531
  _EVENTARCTRIGGERXMATCHINGCRITERIA._serialized_end=617
  _EVENTARCTRIGGERXTIMEOUTS._serialized_start=619
  _EVENTARCTRIGGERXTIMEOUTS._serialized_end=693
  _EVENTARCTRIGGERXTRANSPORTXPUBSUB._serialized_start=695
  _EVENTARCTRIGGERXTRANSPORTXPUBSUB._serialized_end=766
  _EVENTARCTRIGGERXTRANSPORT._serialized_start=768
  _EVENTARCTRIGGERXTRANSPORT._serialized_end=871
  _EVENTARCTRIGGER._serialized_start=874
  _EVENTARCTRIGGER._serialized_end=1526
  _EVENTARCTRIGGER_LABELSENTRY._serialized_start=1481
  _EVENTARCTRIGGER_LABELSENTRY._serialized_end=1526
# @@protoc_insertion_point(module_scope)
